#!/usr/bin/env ruby
# boards.rb
# create index html for blackboard directories

require 'fileutils'
require 'date'

boards = File.expand_path("../../boards", __dir__)
index = "index.php"

def page(date, jpg)
  links = jpg.map do |f|
    base = File.basename f, '.jpg'
    "<img src=\"#{base}.jpg\" alt=\"#{base}\" />"
  end.join "\n"
  html = <<-EOS
<?php header("Cache-Control: max-age=600, must-revalidate"); ?>
<!DOCTYPE html 
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
  <title>MATH UN2010: Linear Algebra (Boards)</title>
  <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
  <link type='text/css' rel='stylesheet' href='style.css' />
</head>
<body>

<h3>#{date}</h3>

<p>
#{links}
</p>

</body>
</html>
EOS
  html
end

Dir.chdir(boards) do
  Dir.glob("*/*").each do |dir|
    date, time = dir.split '/'
    time = { '840' => '8:40 AM', '1010' => '10:10 AM' }[time]
    date = DateTime.parse("#{Date.today.year}-#{date} #{time}").strftime("%A %-d %B %Y %-I:%M%P")
    Dir.chdir(dir) do
      images = Dir.glob("*.jpg").sort
      File.write index, page(date, images)
    end
  end
end
